#ifndef NT2_INCLUDE_CONSTANTS_STIRLINGLARGELIM_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_STIRLINGLARGELIM_HPP_INCLUDED

#include <nt2/euler/include/constants/stirlinglargelim.hpp>

#endif
